Module: BSV::Identity
- Defined in:
- lib/bsv/identity.rb,
lib/bsv/identity/types.rb,
lib/bsv/identity/client.rb,
lib/bsv/identity/constants.rb,
lib/bsv/identity/identity_parser.rb
Overview
Identity module for BSV blockchain.
Provides data structures and constants for resolving and displaying identity information associated with BSV public keys, backed by verifiable certificates managed through the BSV overlay network.
Defined Under Namespace
Modules: Constants, IdentityParser Classes: CertifierInfo, Client, ClientOptions, DisplayableIdentity, IdentityCertificate