Module: BSV::Network::Result

Defined in:
lib/bsv/network/result.rb

Overview

Result module provides three immutable value types for Protocol dispatch outcomes.

All three types share a Predicates mixin with default false implementations. Each type overrides only the predicate that returns true for that type.

Defined Under Namespace

Modules: Predicates Classes: Error, NotFound, Success