Module: BSV::Overlay

Defined in:
lib/bsv/overlay.rb,
lib/bsv/overlay/types.rb,
lib/bsv/overlay/errors.rb,
lib/bsv/overlay/constants.rb,
lib/bsv/overlay/lookup_resolver.rb,
lib/bsv/overlay/topic_broadcaster.rb,
lib/bsv/overlay/lookup_facilitator.rb,
lib/bsv/overlay/admin_token_template.rb,
lib/bsv/overlay/broadcast_facilitator.rb,
lib/bsv/overlay/host_reputation_tracker.rb

Overview

Overlay Services module for BSV blockchain.

Provides foundation types, protocol constants, and error classes for interacting with BSV Overlay Services via the SHIP and SLAP protocols.

Defined Under Namespace

Modules: Constants Classes: AcknowledgementError, AdminTokenTemplate, AdmittanceInstructions, AllHostsRejectedError, BroadcastFacilitator, HTTPSBroadcastFacilitator, HTTPSLookupFacilitator, HostReputationTracker, LookupAnswer, LookupFacilitator, LookupQuestion, LookupResolver, NoCompetentHostsError, OverlayBroadcastResult, OverlayError, TaggedBEEF, TopicBroadcaster

Constant Summary collapse

SHIPBroadcaster =

Alias for TopicBroadcaster.

SHIPBroadcaster and TopicBroadcaster are the same class; the alias exists for compatibility with the Go and TypeScript SDKs where the class is known by both names.

TopicBroadcaster