Module: BSV::Overlay::Constants

Defined in:
lib/bsv/overlay/constants.rb

Overview

Protocol identifiers and network configuration constants for BSV Overlay Services.

Constant Summary collapse

PROTOCOL_SHIP =

Short protocol identifier for Service Host Interconnect.

'SHIP'
PROTOCOL_SLAP =

Short protocol identifier for Service Lookup Availability Protocol.

'SLAP'
PROTOCOL_ID_SHIP =

Full protocol identifier for Service Host Interconnect (display / human-readable form).

'Service Host Interconnect'
PROTOCOL_ID_SLAP =

Full protocol identifier for Service Lookup Availability Protocol (display / human-readable form).

'Service Lookup Availability'
DERIVE_PROTOCOL_SHIP =

BRC-42/43 key-derivation protocol name for Service Host Interconnect. Lowercase as required by the wallet key-derivation validator.

'service host interconnect'
DERIVE_PROTOCOL_SLAP =

BRC-42/43 key-derivation protocol name for Service Lookup Availability. Lowercase as required by the wallet key-derivation validator.

'service lookup availability'
DEFAULT_SLAP_TRACKERS =

Default SLAP tracker URLs for mainnet. These nodes maintain records of which overlay services are available and where.

[
  # BSVA clusters
  'https://overlay-us-1.bsvb.tech',
  'https://overlay-eu-1.bsvb.tech',
  'https://overlay-ap-1.bsvb.tech',

  # Babbage primary overlay service
  'https://users.bapp.dev'
].freeze
DEFAULT_TESTNET_SLAP_TRACKERS =

Default SLAP tracker URLs for testnet.

[
  # Babbage primary testnet overlay service
  'https://testnet-users.bapp.dev'
].freeze
NETWORK_PRESETS =

Network presets mapping network names to their default SLAP tracker lists.

{
  'mainnet' => DEFAULT_SLAP_TRACKERS,
  'testnet' => DEFAULT_TESTNET_SLAP_TRACKERS
}.freeze