Class: BSV::Overlay::LookupQuestion

Inherits:
Object
  • Object
show all
Defined in:
lib/bsv/overlay/types.rb

Overview

The question asked to the Overlay Services Engine when a consumer of state wishes to look up information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service:, query:) ⇒ LookupQuestion

Returns a new instance of LookupQuestion.

Parameters:

  • service (String)
  • query (Hash)


58
59
60
61
# File 'lib/bsv/overlay/types.rb', line 58

def initialize(service:, query:)
  @service = service
  @query = query
end

Instance Attribute Details

#queryHash (readonly)

Returns query forwarded to the Lookup Service; structure depends on the service.

Returns:

  • (Hash)

    query forwarded to the Lookup Service; structure depends on the service



54
55
56
# File 'lib/bsv/overlay/types.rb', line 54

def query
  @query
end

#serviceString (readonly)

Returns identifier of the Lookup Service to query.

Returns:

  • (String)

    identifier of the Lookup Service to query



51
52
53
# File 'lib/bsv/overlay/types.rb', line 51

def service
  @service
end