Class: BSV::Overlay::TaggedBEEF

Inherits:
Object
  • Object
show all
Defined in:
lib/bsv/overlay/types.rb

Overview

Tagged BEEF (Background Evaluation Extended Format) structure.

Comprises a transaction, its SPV information, and the overlay topics where its inclusion is requested.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(beef:, topics:) ⇒ TaggedBEEF

Returns a new instance of TaggedBEEF.

Parameters:

  • beef (String)

    raw binary BEEF-encoded transaction data

  • topics (Array<String>)

    overlay topic names



18
19
20
21
# File 'lib/bsv/overlay/types.rb', line 18

def initialize(beef:, topics:)
  @beef = beef
  @topics = topics
end

Instance Attribute Details

#beefString (readonly)

Returns raw binary BEEF-encoded transaction data.

Returns:

  • (String)

    raw binary BEEF-encoded transaction data



11
12
13
# File 'lib/bsv/overlay/types.rb', line 11

def beef
  @beef
end

#topicsArray<String> (readonly)

Returns overlay topic names where the transaction is to be submitted.

Returns:

  • (Array<String>)

    overlay topic names where the transaction is to be submitted



14
15
16
# File 'lib/bsv/overlay/types.rb', line 14

def topics
  @topics
end