Exception: BSV::Wallet::UnsupportedActionError

Inherits:
Error
  • Object
show all
Defined in:
lib/bsv/wallet/errors.rb

Overview

Code 2 — operation not supported by this wallet implementation.

Instance Attribute Summary

Attributes inherited from Error

#code, #wallet_stack

Instance Method Summary collapse

Methods inherited from Error

#to_wire

Constructor Details

#initialize(message = 'this method is not supported by this wallet implementation', stack: '') ⇒ UnsupportedActionError

Returns a new instance of UnsupportedActionError.



25
26
27
# File 'lib/bsv/wallet/errors.rb', line 25

def initialize(message = 'this method is not supported by this wallet implementation', stack: '')
  super(message, code: 2, stack: stack)
end