Module: BSV::Wallet::WalletWire
- Included in:
- Substrates::HTTPWalletWire, WalletWireProcessor
- Defined in:
- lib/bsv/wallet/wallet_wire.rb
Overview
Abstract binary transport for BRC-103 wallet communication.
Include this module and implement #transmit_to_wallet to provide a concrete transport (e.g. HTTP, in-process loopback, Unix socket).
Instance Method Summary collapse
-
#transmit_to_wallet(message) ⇒ String
Transmit a binary request frame to the wallet and return the binary result frame.
Instance Method Details
#transmit_to_wallet(message) ⇒ String
Transmit a binary request frame to the wallet and return the binary result frame.
15 16 17 |
# File 'lib/bsv/wallet/wallet_wire.rb', line 15 def transmit_to_wallet() raise NotImplementedError, "#{self.class}#transmit_to_wallet is not implemented" end |