Class: BSV::Overlay::LookupAnswer
- Inherits:
-
Object
- Object
- BSV::Overlay::LookupAnswer
- Defined in:
- lib/bsv/overlay/types.rb
Overview
How the Overlay Services Engine responds to a LookupQuestion.
Instance Attribute Summary collapse
-
#outputs ⇒ Array
readonly
Outputs or freeform response data from the Lookup Service.
-
#type ⇒ String
readonly
Response type (e.g. ‘output-list’).
Instance Method Summary collapse
-
#initialize(type:, outputs:) ⇒ LookupAnswer
constructor
A new instance of LookupAnswer.
Constructor Details
#initialize(type:, outputs:) ⇒ LookupAnswer
Returns a new instance of LookupAnswer.
74 75 76 77 |
# File 'lib/bsv/overlay/types.rb', line 74 def initialize(type:, outputs:) @type = type @outputs = outputs end |
Instance Attribute Details
#outputs ⇒ Array (readonly)
Returns outputs or freeform response data from the Lookup Service.
70 71 72 |
# File 'lib/bsv/overlay/types.rb', line 70 def outputs @outputs end |
#type ⇒ String (readonly)
Returns response type (e.g. ‘output-list’).
67 68 69 |
# File 'lib/bsv/overlay/types.rb', line 67 def type @type end |