Class: BSV::Overlay::LookupQuestion
- Inherits:
-
Object
- Object
- BSV::Overlay::LookupQuestion
- Defined in:
- lib/bsv/overlay/types.rb
Overview
The question asked to the Overlay Services Engine when a consumer of state wishes to look up information.
Instance Attribute Summary collapse
-
#query ⇒ Hash
readonly
Query forwarded to the Lookup Service; structure depends on the service.
-
#service ⇒ String
readonly
Identifier of the Lookup Service to query.
Instance Method Summary collapse
-
#initialize(service:, query:) ⇒ LookupQuestion
constructor
A new instance of LookupQuestion.
Constructor Details
#initialize(service:, query:) ⇒ LookupQuestion
Returns a new instance of LookupQuestion.
58 59 60 61 |
# File 'lib/bsv/overlay/types.rb', line 58 def initialize(service:, query:) @service = service @query = query end |
Instance Attribute Details
#query ⇒ Hash (readonly)
Returns query forwarded to the Lookup Service; structure depends on the service.
54 55 56 |
# File 'lib/bsv/overlay/types.rb', line 54 def query @query end |
#service ⇒ String (readonly)
Returns identifier of the Lookup Service to query.
51 52 53 |
# File 'lib/bsv/overlay/types.rb', line 51 def service @service end |