Class: BSV::Registry::CertificateDefinitionData
- Inherits:
-
Object
- Object
- BSV::Registry::CertificateDefinitionData
- Defined in:
- lib/bsv/registry/types.rb
Overview
Registry data for a certificate type definition.
Instance Attribute Summary collapse
-
#definition_type ⇒ String
readonly
Always DefinitionType::CERTIFICATE.
-
#description ⇒ String
readonly
Description of the certificate type’s purpose.
-
#documentation_url ⇒ String
readonly
URL to the certificate type documentation.
-
#fields ⇒ Hash<String, CertificateFieldDescriptor>
readonly
Field schema descriptors.
-
#icon_url ⇒ String
readonly
URL or opaque string for the certificate type icon.
-
#name ⇒ String
readonly
Human-readable name.
-
#registry_operator ⇒ String?
readonly
Public key hex of the registry operator.
-
#type ⇒ String
readonly
Base64-encoded certificate type identifier.
Instance Method Summary collapse
-
#initialize(type:, name:, icon_url:, description:, documentation_url:, fields: {}, registry_operator: nil) ⇒ CertificateDefinitionData
constructor
A new instance of CertificateDefinitionData.
Constructor Details
#initialize(type:, name:, icon_url:, description:, documentation_url:, fields: {}, registry_operator: nil) ⇒ CertificateDefinitionData
Returns a new instance of CertificateDefinitionData.
170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/bsv/registry/types.rb', line 170 def initialize(type:, name:, icon_url:, description:, documentation_url:, fields: {}, registry_operator: nil) @definition_type = DefinitionType::CERTIFICATE @type = type @name = name @icon_url = icon_url @description = description @documentation_url = documentation_url @fields = fields @registry_operator = registry_operator end |
Instance Attribute Details
#definition_type ⇒ String (readonly)
Returns always DefinitionType::CERTIFICATE.
140 141 142 |
# File 'lib/bsv/registry/types.rb', line 140 def definition_type @definition_type end |
#description ⇒ String (readonly)
Returns description of the certificate type’s purpose.
152 153 154 |
# File 'lib/bsv/registry/types.rb', line 152 def description @description end |
#documentation_url ⇒ String (readonly)
Returns URL to the certificate type documentation.
155 156 157 |
# File 'lib/bsv/registry/types.rb', line 155 def documentation_url @documentation_url end |
#fields ⇒ Hash<String, CertificateFieldDescriptor> (readonly)
Returns field schema descriptors.
158 159 160 |
# File 'lib/bsv/registry/types.rb', line 158 def fields @fields end |
#icon_url ⇒ String (readonly)
Returns URL or opaque string for the certificate type icon.
149 150 151 |
# File 'lib/bsv/registry/types.rb', line 149 def icon_url @icon_url end |
#name ⇒ String (readonly)
Returns human-readable name.
146 147 148 |
# File 'lib/bsv/registry/types.rb', line 146 def name @name end |
#registry_operator ⇒ String? (readonly)
Returns public key hex of the registry operator.
161 162 163 |
# File 'lib/bsv/registry/types.rb', line 161 def registry_operator @registry_operator end |
#type ⇒ String (readonly)
Returns Base64-encoded certificate type identifier.
143 144 145 |
# File 'lib/bsv/registry/types.rb', line 143 def type @type end |