Class: BSV::Transaction::FeeModel
- Inherits:
-
Object
- Object
- BSV::Transaction::FeeModel
- Defined in:
- lib/bsv/transaction/fee_model.rb
Overview
Base class for fee models that compute transaction fees.
Fee models determine how many satoshis a transaction should pay in fees based on its size or other properties. Subclasses must implement #compute_fee.
Direct Known Subclasses
BSV::Transaction::FeeModels::LivePolicy, BSV::Transaction::FeeModels::SatoshisPerKilobyte
Instance Method Summary collapse
-
#compute_fee(_transaction) ⇒ Integer
Compute the fee for a transaction.
Instance Method Details
#compute_fee(_transaction) ⇒ Integer
Compute the fee for a transaction.
23 24 25 |
# File 'lib/bsv/transaction/fee_model.rb', line 23 def compute_fee(_transaction) raise NotImplementedError, "#{self.class}#compute_fee must be implemented" end |