Exception: BSV::Wallet::UnsupportedActionError
- Defined in:
- lib/bsv/wallet/errors.rb
Overview
Code 2 — operation not supported by this wallet implementation.
Instance Attribute Summary
Attributes inherited from Error
Instance Method Summary collapse
-
#initialize(message = 'this method is not supported by this wallet implementation', stack: '') ⇒ UnsupportedActionError
constructor
A new instance of UnsupportedActionError.
Methods inherited from Error
Constructor Details
#initialize(message = 'this method is not supported by this wallet implementation', stack: '') ⇒ UnsupportedActionError
Returns a new instance of UnsupportedActionError.
25 26 27 |
# File 'lib/bsv/wallet/errors.rb', line 25 def initialize( = 'this method is not supported by this wallet implementation', stack: '') super(, code: 2, stack: stack) end |